@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.0.3
+#www2sms.py v1.0.4
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #--------------------------------------------------------------------------------
 #
 
-import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution, re
+import os, errno, pwd, sys, math, sqlite3, time, calendar, evolution, re, socket
 import ctypes, uuid, glib, gobject
 from PyQt4 import QtCore
 from PyQt4.QtGui import QApplication, QMainWindow, QDialog, QPushButton, QMessageBox
@@ -328,6 +328,15 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
 	# Method which is called when we want to send the sms. It actually calls a method on the providers class
 	def on_send_clicked(self):
+		# Check if we are online
+		address = "heise.de"
+		s = socket.socket()
+		port = 80 # port number is a number, not string
+		try:
+			s.connect((address, port))
+		except Exception, e:
+			QMessageBox.warning(self, 'www2sms', 'Please connect to the Internet bofore sending the SMS')
+			return
 	    	# Read the provider to use
 		PROVIDER = unicode(AccSet.ui.comboBox_SetupProvider.currentText())
 		provider_index = AccSet.ui.comboBox_SetupProvider.findText(PROVIDER)
@@ -382,7 +391,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 	# Method which is called from providers class when the sms was successfully send
 	def on_send_success(self,MSG,NUM):
 		QMessageBox.information(self, 'www2sms', MSG)
-		self.ui.lineEdit_Number.clear()
+		#self.ui.lineEdit_Number.clear()
 		self.ui.plainTextEdit_SMS.clear()
 		# grp is last 7 (or fewer) digits/whatever
 		grp = NUM[-7:]
@@ -496,7 +505,7 @@ def put_to_sent_sms(name, number, uniqueid, groupid, message):
 	event._mask       |= 1 << 17
 	event.fld_group_uid = groupid
 	event._mask       |= 1 << 16
-	event.fld_free_text = message
+	event.fld_free_text = message.encode('utf-8')
 
 	#print "adding event..."
 	rtcom.rtcom_el_add_event.argtypes = [el, ctypes.c_void_p, ctypes.c_void_p]
