@@ -50,7 +50,7 @@ class provider():
 	def sendSMS(self, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
 		return False, "SMS sending not implemented"
 
-# o2online.de 2.1
+# o2online.de 2.2
 class provider_o2online_de(provider):
 	def getName(self):
 		return 'o2online (Deutschland)'
@@ -347,7 +347,7 @@ class provider_o2online_de(provider):
 			# Convert the "unicode" string obtained from the QSTRING to "str"
 			# Otherwise mechanize will bail out with:
 			# UnicodeEncodeError: 'ascii' codec can't encode characters in position
-			br.form['SMSText'] = SMSTEXT.encode('utf-8')
+			br.form['SMSText'] = SMSTEXT.encode(br.encoding())
 			# Check for FlashSMS
 			if FLASH :
 				br.form['FlagFlash'] = '1'
@@ -458,7 +458,7 @@ class provider_vodafone_nl(provider):
 		try:
 			br.select_form(name='controle')
 			br.form['phoneNumber'] = number
-			br.form['body'] = SMSTEXT.encode('utf-8')
+			br.form['body'] = SMSTEXT.encode(br.encoding())
 			br.submit()
 		except:
 			print response
